checkRequire("Lua_ShopSecondItem");
Lua_ShopPanel = class("Lua_ShopPanel", Lua_DisplayObject);
function Lua_ShopPanel:ctor(p)
	self:superCall("ctor", p, "ShopPanel_skin");
end

function Lua_ShopPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.itemList = Lua_DragList.new(self.content, 720, 586 + self.adaptHeight / 2, Lua_AxisDefine.Vertical);
	self.itemList.tweenId = 2013;
	self.itemList:setListCell(Lua_ShopSecondItem, 720, 217, 1);
	self.itemList:setRectPivot(1);
	-- self.itemList:setRectAnchor(1);
	self.itemList:setCellSpacing(-5, 16);
	-- self.itemList:setLocation(0, -561, 0);
	self.itemList:setLocation(0, 159, 0);

	self.infoBg:setEnable(false);
	self.refreshBtn:setEnable(false);
	self.refreshBtn:addClickFuntion(self, self.onRefreshBtnClick);

	self:addLuaEvent("UPDATE_SHOP_INFO", self, self.updateShowInfo);
end

function Lua_ShopPanel:onScreenResize(adaptHeight)
	if self.adaptHeight ~= adaptHeight then
		self:superCall("onScreenResize", adaptHeight);
		self.itemList:setContentRect(720, 586 + adaptHeight / 2);
	end
end

function Lua_ShopPanel:setData(data)
	self.data = data;
end

function Lua_ShopPanel:updateShowInfo()
	if self.data == nil then
		return;
	end
	self:setShowList();
	
	-- 显示刷新处理
	if self.data.refresh ~= nil then
		local str = spliceIconStrById(self.data.cost_money);
		if self.data.shopType == Lua_ShopData.HERO_SHOP then
			if self.data.leftTimes > 0 and self.data.leftFreeTimes > 0 then
				self.refreshBtn:setLangValue(125026);
			else
				self.refreshBtn.label = LanUtil.formateStr(125017, str, numberTrans(self.data.cost));
			end
			self.remainTimeTxt.text = LanUtil.formateStr(125029, self.data.leftTimes, self.data.totalTimes);
			self.remainTimeTxt:setLocation(-108, 163, 0);
		elseif self.data.shopType == Lua_ShopData.TALENT_SHOP then
			if self.data.leftTimes > 0 then 
				if self.data.leftFreeTimes > 0 then
					self.refreshBtn.label = LanUtil.formateStr(125028, self.data.leftFreeTimes, self.data.free_refresh);
				else
					self.refreshBtn.label = LanUtil.formateStr(125017, str, numberTrans(self.data.cost));
				end
			else
				self.refreshBtn:setLangValue(125041);
			end
			self.remainTimeTxt.text = LanUtil.formateStr(125029, self.data.leftTimes, self.data.totalTimes);
			self.remainTimeTxt:setLocation(-108, 150, 0);
			self.refreshTimeTxt:setLocation(-108, 175, 0);
			self.showTimeStr = LanUtil.getValue(125027);
		elseif self.data.shopType == Lua_ShopData.TREASURE_SHOP then
			self.refreshBtn.label = LanUtil.formateStr(125030, str, numberTrans(self.data.cost));
			self.showTimeStr = LanUtil.getValue(125031);
			self.refreshTimeTxt:setLocation(-108, 163, 0);
		end
		self.refreshBtn:setGray(self.data.leftTimes <= 0);

		if self.showTimeStr ~= nil then
			self:startTimer();
			self:updateTimer();
		end	
	end
	self.infoBg:setEnable(self.data.refresh ~= nil);
	self.refreshBtn:setEnable(self.data.refresh ~= nil);
end

function Lua_ShopPanel:setShowList()
	local list = DataCenter.shopData:getCurShopItemList(self.data.shopType);
	local index = 1;
	local num = 0;
	local showList = {};
	for i = 1, #list do
		if showList[index] == nil then
			showList[index] = Array();
		end
		showList[index]:add(list[i]);

		num = num + 1;
		if num >= 4 then
			index = index + 1;
			num = 0;
		end
	end
	self.itemList:setArrayData(showList);
end

function Lua_ShopPanel:startTimer()
	if not self.isTimer then
		self.isTimer = true;
		self:updateTimer();
		self:addTimer("updateTimer", 1, self, self.updateTimer);
	end
end

function Lua_ShopPanel:updateTimer()
	local time = self.data.nextTicks - os.time();
	if time <= 0 then
		time = 0;
		self.isTimer = false;
		self:removeTimer(self, self.updateTimer);
	end
	local str = TimeTransform.getInstance():transSeconds6(time, true, true);
	self.refreshTimeTxt.text = LanUtil.formateStr(self.showTimeStr, Lua_ColorDefine.getColorStr("3BF25A", str));
end

function Lua_ShopPanel:onRefreshBtnClick(go)
	if self.data == nil then
		return;
	end
	if self.clickTime ~= nil and getTime() - self.clickTime < 0.3 then
		OperateAlert.showLangValue(10031);
		return;
	end
	self.clickTime = getTime();
	
	if self.data.leftFreeTimes > 0 then -- 免费刷新
		Lua_ProxyManager.getProxy("Lua_ShopProxy"):sRefreshShop(self.data.shopType, 0);
	elseif self.data.leftTimes > 0 then -- 自费刷新
		if DataCenter.moneyData:isMoney(self.data.cost_money) then
			if not DataCenter.moneyData:isMoneyEnough(self.data.cost_money, self.data.cost, true, true) then
				return;
			end
		else
			if DataCenter.packData:getItemCountById(self.data.cost_money) < self.data.cost then
				DataCenter.packUtil:openPathWindow(self.data.cost_money, false);
				return;
			end
		end
		Lua_ProxyManager.getProxy("Lua_ShopProxy"):sRefreshShop(self.data.shopType, 1);
	elseif self.data.leftBuyTimes > 0 then -- 购买刷新
		Lua_WindowUtil.openWin("Lua_BuyTimesWindow", Lua_WinParam.ACTION_OPEN, self.data);
	else
		OperateAlert.showLangValue(125054);
	end
end

function Lua_ShopPanel:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self.data = nil;
	self:removeTimer(self, self.updateTimer);
	self:superCall("dispose");
end