checkRequire("Lua_DialogueBubbleItem");
checkRequire("Lua_SpiritShopSecondItem");
Lua_SpiritShopPanel = class("Lua_SpiritShopPanel", Lua_DisplayObject);
function Lua_SpiritShopPanel:ctor(p)
	self:superCall("ctor", p, "SpiritShopPanel_skin");
end

function Lua_SpiritShopPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.moneyItemArr = Array();

	self.itemList = Lua_DragList.new(self.content, 720, 602 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList.tweenId = 2013;
	self.itemList:setListCell(Lua_SpiritShopSecondItem, 720, 278, 1);
	self.itemList:setRectPivot(1);
	-- self.itemList:setRectAnchor(1);
	self.itemList:setCellSpacing(-5, 0);
	-- self.itemList:setLocation(0, -545, 0);
	self.itemList:setLocation(0, 175, 0);

	self.refreshBtn:addClickFuntion(self, self.onRefreshBtnClick);
	self.introduceSp:addClickFuntion(self, self.onIntroduceSpClick);

	self:addLuaEvent("UPDATE_SHOP_INFO", self, self.updateShowInfo);
	self:addLuaEvent("REFRESH_SHOP_INFO", self, self.updateShopTypePanel); -- 到达商店刷新时间
	self:addLuaEvent("SPIRIT_SHOP_EFFECT_CALLFUN_CLICK", self, self.showItemEffect); -- 到达商店刷新时间
end

function Lua_SpiritShopPanel:setData(data)
	-- print(data.shopType, Lua_ShopData.SPIRIT_SHOP);
	self.data = data;
end

function Lua_SpiritShopPanel:onScreenResize(adaptHeight)
	if self.adaptHeight ~= adaptHeight then
		self:superCall("onScreenResize", adaptHeight);
		self.itemList:setContentRect(720, 602 + adaptHeight);
	end
end

function Lua_SpiritShopPanel:updateShowInfo()
	local list = DataCenter.shopData:getCurShopItemList(self.data.shopType);
	local index = 1;
	local num = 0;
	local showList = {};
	for i = 1, #list do
		if showList[index] == nil then
			showList[index] = Array();
		end
		showList[index]:add(list[i]);

		num = num + 1;
		if num >= 3 then
			index = index + 1;
			num = 0;
		end
	end
	self.itemList:setArrayData(showList, nil);

	if self.data.leftFreeTimes > 0 then
		self.refreshBtn.label = LanUtil.formateStr(125036, self.data.leftFreeTimes, self.data.free_refresh);
		self.refreshBtn:setStyle(5);
	else
		if self.data.leftTimes > 0 then
			self.refreshBtn.label = LanUtil.formateStr(125017, spliceIconStrById(self.data.cost_money), numberTrans(self.data.cost));
			self.refreshBtn:setStyle(5);
		else
			self.refreshBtn:setLangValue(125041);
			self.refreshBtn:setStyle(7);
		end
	end
    
    local str;
    if tonumber(self.data.leftTimes) > 0 then
		str = Lua_ColorDefine.getColorStr("3BF25A", self.data.leftTimes);
	else
		str = Lua_ColorDefine.getColorStr("FF4B4C", self.data.leftTimes);
	end
	self.remainTimeTxt.text = LanUtil.formateStr(125037, str, self.data.totalTimes);

	self:startTimer();
	self:updateTimer();
	-- self:checkWinGuide(); -- 检测引导
end

function Lua_SpiritShopPanel:startTimer()
	if not self.isTimer then
		self.isTimer = true;
		self:addTimer("updateTimer", 1, self, self.updateTimer);
	end
end

function Lua_SpiritShopPanel:updateTimer()
	local time = self.data.nextTicks - os.time();
	if time <= 0 then
		time = 0;
		self.isTimer = false;
		self:removeTimer(self, self.updateTimer);
	end
	local str = TimeTransform.getInstance():transSeconds6(time, true, true);
	self.refreshTimeTxt.text = Lua_ColorDefine.getColorStr("3BF25A", str);
end

function Lua_SpiritShopPanel:onRefreshBtnClick(go)
	if self.clickTime ~= nil and getTime() - self.clickTime < 0.3 then
		OperateAlert.showLangValue(10031);
		return;
	end
	self.clickTime = getTime();
	
	if self.data.leftFreeTimes > 0 then -- 免费刷新
		Lua_ProxyManager.getProxy("Lua_ShopProxy"):sRefreshShop(self.data.shopType, 0);
		self:showItemEffect(true);
	elseif self.data.leftTimes > 0 then -- 自费刷新
		if DataCenter.moneyData:isMoney(self.data.cost_money) then
			if not DataCenter.moneyData:isMoneyEnough(self.data.cost_money, self.data.cost, true, true) then
				return;
			end
		else
			if DataCenter.packData:getItemCountById(self.data.cost_money) < self.data.cost then
				DataCenter.packUtil:openPathWindow(self.data.cost_money, false);
				return;
			end
		end
		Lua_ProxyManager.getProxy("Lua_ShopProxy"):sRefreshShop(self.data.shopType, 1);
		self:showItemEffect(true);
	elseif self.data.leftBuyTimes > 0 then -- 购买刷新
		Lua_WindowUtil.openWin("Lua_BuyTimesWindow", Lua_WinParam.ACTION_OPEN, self.data);
		self:showItemEffect(true);
	else
		OperateAlert.showLangValue(125020);
	end
end

function Lua_SpiritShopPanel:showItemEffect(bShow)
	local arr = self.itemList.showList;
	for i = 1, arr:getSize() do
		for j = 1, arr[i].shopItemArr:getSize() do
			arr[i].shopItemArr[j]:showHighlightEff(bShow);
		end
	end
end

function Lua_SpiritShopPanel:onIntroduceSpClick()
	local tipsData = { des = LanUtil.getValue(125043), posX = 180, posY = -303 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_SpiritShopPanel:updateShopTypePanel()
	Lua_ProxyManager.getProxy("Lua_ShopProxy"):sShopInfo(Lua_ShopData.SPIRIT_SHOP);
end

function Lua_SpiritShopPanel:dispose()
	if self.moneyItemArr ~= nil then
		self.moneyItemArr:dispose();
		self.moneyItemArr:clear();
		self.moneyItemArr = nil;
	end
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	DataCenter.shopData:dispose();
	self:superCall("dispose");
end










-- -- 引导同步
-- function Lua_SpiritShopPanel:updateGuide(guide, info)
-- 	if info == nil then
-- 		return;
-- 	end

-- 	-- 检测目标位置，返回path
-- 	local itemId = info.itemId;
-- 	if itemId ~= nil and self.itemArr ~= nil then
-- 		local num = info.count ~= nil and info.count or 0;
-- 		local len = self.itemArr:getSize();
-- 		for i = 1, len do
-- 			local item = self.itemArr[i];
-- 			local vo = item.showData;
-- 			if vo ~= nil and vo.itemId == itemId then
-- 				DataCenter.guideCommonData.guideClickObjTarget = item.content;
-- 				Lua_MsgUtil.callFunc("Guide_WinSync_Complete", guide);
-- 				return;	
-- 			end
-- 		end
-- 	end
-- end