Lua_ShopItem = class("Lua_ShopItem", Lua_DisplayObject);
function Lua_ShopItem:ctor(p, skin)
	self:superCall("ctor", p, skin or "ShopItem_skin");
end

function Lua_ShopItem:buildShowItem()
	self:superCall("buildShowItem");

	self.item = Lua_ItemIcon.new(self.content);
	self.item:setCanClick(false);
	self.item:setSiblingIndex(2);
	self.item:setLocation(0.5, 28, 0);
	self.item:setScale(0.72, 0.72);
end

function Lua_ShopItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.itemId = data.itemVo.id;
	self.item:setData(data.itemVo);
	self.item:setGray(false);
	self.deserveIcon:setEnable(data.deserve == 1); -- 必买
	if data.discount > 0 then
		self.leftTop:SetActive(true);
		self.leftBg:setAltas("shop_atlas_1", "xui_sd_label_" .. data.discount);
	-- 	self.leftTopLabel.text = LanUtil.formateStr(125013, data.discount); -- 折扣
	-- elseif data.recommend > 0 then
	-- 	self.leftTop:SetActive(true);
	-- 	self.leftBg:setAltas("shop_atlas_1", "ui_sd_label_01");
	-- 	self.leftTopLabel:setLangValue(125012); -- 推荐
	else
		self.leftTop:SetActive(false);
	end

	-- 公会等级不符合该商品的解锁条件，5为公会，isLeagueOpen：该商品是否符合开启条件
	self.isLeagueNotOpen = data.shopType == 5 and (not data.isLeagueOpen or not data.notOpenDayLimit or DataCenter.roleData.league_id == 0);
	if self.data.isSoldOut then
		if self.isLeagueNotOpen then -- 公会
			self.soldOut:SetActive(false);
		else
			self.soldOut:SetActive(true);
		end
	else
		self.soldOut:SetActive(false);
	end

	if data.vip_level > DataCenter.roleData.vip then
		self.conditionTxt.text = LanUtil.formateStr(125003, data.vip_level);
		self.costObj:SetActive(false);
	else
		self.conditionTxt.text = "";
		self.costObj:SetActive(true);

		local toolVo = Lua_ToolVo.createToolVo(data.moneyType);
		if toolVo ~= nil then
			self.costIcon:setAltas(toolVo.iconAtlas, toolVo.iconSprite);
			self.costIcon:SetDimensions(toolVo.iconWidth, toolVo.iconHeight);
		end
			
		if data.moneyCount ~= 0 then
			if DataCenter.packData:getItemCountById(data.moneyType) < data.moneyCount then
				self.costCount.text = LanUtil.formateStr(125044, numberTrans(data.moneyCount));
			else
				self.costCount.text = numberTrans(data.moneyCount);
			end
		else
			self.costCount:setLangValue(125011);
		end
		self.costCount:resetSize();
		local maxY = self.costCount.posX + self.costCount.width;
		local minY = self.costIcon.posX - self.costIcon.width;
		local changePosY = (maxY - minY) / 2;
		self.costIcon:setLocation(-changePosY + self.costIcon.width, self.costIcon.posY, 0);
		self.costCount:setLocation(changePosY - self.costCount.width, self.costCount.posY, 0);
	end
	
	if data.shopType == Lua_ShopData.LEAGUE_SHOP then --社区（联盟）
		if not data.isLeagueOpen then
			self.timesTxt.text = LanUtil.formateStr(125042, data.communityLevel);
			self.item:setGray(true);
		else
			if not data.notOpenDayLimit then
				self.timesTxt.text = LanUtil.formateStr(125055, data.open_days[1]);
				self.item:setGray(true);
			else
				self:showCustomLimit();
			end
		end
	elseif data.shopType == Lua_ShopData.HERO_SHOP then
		self.timesTxt.text = LanUtil.formateStr(125032, numberTrans(DataCenter.packData:getItemCountById(data.itemVo.id)));
	elseif data.shopType == Lua_ShopData.TALENT_SHOP then
		self.timesTxt.text = LanUtil.formateStr(125033, data.leftTimes, data.limitTimes);
	elseif data.shopType == Lua_ShopData.PEAK_SHOP and DataCenter.shopData.segmentLv < data.peak_duel_lvl_id then
		local segmentInfo = DataCenter.peakDuelUtil:getSegmentInfoByid(data.peak_duel_lvl_id);
		self.timesTxt.text = LanUtil.formateStr(125038, segmentInfo.name);
		self.item:setGray(true);
	elseif data.shopType == Lua_ShopData.EQUIP_SHOP and data.limit_grade > DataCenter.equipCopyData.max_difficulty then --魔灵商店
		self.timesTxt.text = LanUtil.formateStr(125050, data.limit_grade);
		self.item:setGray(true);
	elseif data.shopType == Lua_ShopData.DOMAIN_SHOP and not data.isDomianUnlock then
		local cond = data.domain_floor;
		if cond[1] == 1 then
			self.timesTxt.text = LanUtil.formateStr(125056, cond[2]);
		else
			self.timesTxt.text = LanUtil.formateStr(125057, cond[2], cond[3]);
		end
		self.item:setGray(true);
	elseif data.shopType == Lua_ShopData.WILD_SECRET_SHOP and not data.isUnLock then
		local config = DataCenter.wildSecretUtil:getStageConfig(data.stage_cond[2]);
		if config ~= nil then
			self.timesTxt.text = LanUtil.formateStr(125064, config.floor, config.stage);
		end
		self.item:setGray(true);
	elseif data.shopType == Lua_ShopData.WAR_SHOP and not data.isUnLock then
		self.timesTxt.text = LanUtil.formateStr(125065, data.stage_cond[2]);
		self.item:setGray(true);
	elseif data.isPreview then
		if DataCenter.roleData.level < data.role_level[1] then
			self.timesTxt.text = LanUtil.formateStr(125061, data.role_level[1]);
		else
			self.timesTxt.text = LanUtil.getValue(125063);
		end
		self.item:setGray(true);
	else
		self:showCustomLimit();
	end

	self.timesTxt:resetSize();
	if self.timesTxt.width > 140 then
		self.timesTxt:setEnable(false);
		if self.scrollText == nil then
			self.scrollText = Lua_ScrollText.new(self.content, Lua_AxisDefine.Horizontal, 140, 35);
			self.scrollText:setLocation(0, -31, 0);
			self.scrollText:setTextStyle(140, 35, Lua_MyUISettings.defaultFontName, 18, "5E5442", 0, "FFFFFF");
		end
		self.scrollText:setEnable(true);
		self.scrollText:setShowTxt(self.timesTxt.text);
	else
		self.timesTxt:setEnable(true);
		if self.scrollText then
			self.scrollText:setEnable(false);
		end
	end
	self:showHighlightEff(data.highlightEff);
end

function Lua_ShopItem:showCustomLimit()
	local str = self.data.leftTimes.."/"..self.data.limitTimes;
	if self.data.limit_type == 1 then
		self.timesTxt.text = LanUtil.formateStr(125000, str);
	elseif self.data.limit_type == 2 then
		self.timesTxt.text = LanUtil.formateStr(125001, str);
	elseif self.data.limit_type == 3 then
		self.timesTxt.text = LanUtil.formateStr(125002, str);
	elseif self.data.limit_type == 4 then
		self.timesTxt.text = LanUtil.formateStr(125040, str);
	else
		self.timesTxt.text = "";
	end
end

function Lua_ShopItem:showHighlightEff(effectName)
	if effectName ~= nil then
		if self.highlightEff == nil then
			self.highlightEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/"..effectName, effectName, 0, -2);
			self.highlightEff:SetRenderQueue(5, 1, UIEffect.NormalSort);
		end
		self.highlightEff:setEnable(true);
	else
		if self.highlightEff ~= nil then
			self.highlightEff:setEnable(false);
		end
	end
end

function Lua_ShopItem:checkOutBound(showRect)
	local rect = Lua_Rectangle.new(self.itemX - 50, self.itemY - 50, 100, 100);
	if showRect:containeRect(rect) == true then
		self.item:showEffect(true);
		if self.data.highlightEff ~= nil and self.highlightEff ~= nil then
			self.highlightEff:setEnable(true);
		end
	else
		self.item:showEffect(false);
		if self.highlightEff ~= nil then
			self.highlightEff:setEnable(false);
		end
	end
end

function Lua_ShopItem:onPressClick()
	-- 是否点击商品道具
	local winPos = LuaUtil.getTouchPosInverseObj(self.mainContent);
	if self.item:checkInBound(winPos.x, winPos.y) then
		local tvo = Lua_ToolVo.createToolVo(self.itemId);
		DataCenter.packUtil:showItemInfo(tvo);
		return;
	end

	-- 购买
	if self.data ~= nil then
		if self.isLeagueNotOpen then --社区（联盟）
			if DataCenter.roleData.league_id == 0 then
				OperateAlert.showLangValue(125060);
			elseif not self.data.isLeagueOpen then
				OperateAlert.show(LanUtil.formateStr(125042, self.data.communityLevel));
			elseif not self.data.notOpenDayLimit then
				OperateAlert.show(LanUtil.formateStr(125055, self.data.open_days[1]));
			end
			return;
		end

		if self.data.shopType == Lua_ShopData.PEAK_SHOP and DataCenter.shopData.segmentLv < self.data.peak_duel_lvl_id then
			local segmentInfo = DataCenter.peakDuelUtil:getSegmentInfoByid(self.data.peak_duel_lvl_id);
			OperateAlert.show(LanUtil.formateStr(125039, segmentInfo.name));
			return;
		elseif self.data.shopType == Lua_ShopData.EQUIP_SHOP and self.data.limit_grade > DataCenter.equipCopyData.max_difficulty then --魔灵商店
			OperateAlert.show(LanUtil.formateStr(125049, self.data.limit_grade));
			return;
		elseif self.data.shopType == Lua_ShopData.DOMAIN_SHOP and not self.data.isDomianUnlock then
			local cond = self.data.domain_floor;
			if cond[1] == 1 then
				OperateAlert.show(LanUtil.formateStr(125058, cond[2]));
			else
				OperateAlert.show(LanUtil.formateStr(125059, cond[2], cond[3]));
			end
			return;
		elseif self.data.shopType == Lua_ShopData.WILD_SECRET_SHOP and not self.data.isUnLock then
			local config = DataCenter.wildSecretUtil:getStageConfig(self.data.stage_cond[2]);
			if config ~= nil then
				OperateAlert.show(LanUtil.formateStr(125064, config.floor, config.stage));
			end
			return;
		elseif self.data.shopType == Lua_ShopData.WAR_SHOP and not self.data.isUnLock then
			OperateAlert.show(LanUtil.formateStr(125065, self.data.stage_cond[2]));
			return;
		elseif self.data.isPreview then
			if DataCenter.roleData.level < self.data.role_level[1] then
				OperateAlert.show(LanUtil.formateStr(125062, self.data.role_level[1]));
			else
				OperateAlert.showLangValue(125063);
			end
			return;
		end

		if self.data.isSoldOut then
			OperateAlert.showLangValue(125014);
		elseif self.data.vip_level > DataCenter.roleData.vip then
			OperateAlert.showLangValue(125021);
		else
			if DataCenter.moneyData:isMoneyEnough(self.data.moneyType, self.data.moneyCount, true, true) then
				local param = {
					id = self.data.itemVo.id, -- 购买道具id
					itemCount = self.data.itemVo.count, -- 购买一份商品所携带的数量
					limitCount = self.data.leftTimes, -- 限购数量，小于0不显示， = 0显示不限购， 默认为1,
					costId = self.data.moneyType, -- 消耗道具id
					costCount = self.data.moneyCount, -- 消耗道具数量
					tipStr = "",
					isShowTipWindow = true, -- 点击购买按钮时，是否显示提示窗口
					isShowBackBtn = false, -- 是否显示返回按钮
					cancelBtnStr = LanUtil.getValue(125051), -- 默认取消
					sureBtnStr = LanUtil.getValue(125052), -- 默认确定
					owner = self, 
					callFunc = self.onSureBuy, -- 回调事件
					priceStyle = 1, -- 价格显示类型
					font_size = 26 -- tipWindow文本字体大小
				};
				Lua_WindowUtil.openWin("Lua_ShoppingGoodsWindow", Lua_WinParam.ACTION_OPEN, param);
			end
		end
	end
end

function Lua_ShopItem:onSureBuy(itemId, selectNum)
	Lua_ProxyManager.getProxy("Lua_ShopProxy"):sBuyShopItem(self.data.id, self.data.shopType, selectNum, self.data.index);
end

-- 判断是否范围内
function Lua_ShopItem:checkInBound(posX, posY)
	local half_w = self.bg.width * self.bg.scaleX / 2;
	local half_h = self.bg.height * self.bg.scaleY  / 2;
	self.minX = self.posX - half_w;
	self.maxX = self.posX + half_w;
	self.minY = self.posY - half_h;
	self.maxY = self.posY + half_h;
	return posX >= self.minX and posX <= self.maxX and posY >= self.minY and posY <= self.maxY;
end

function Lua_ShopItem:dispose()
	if self.data ~= nil then
		self.data.highlightEff = nil;
		self.data = nil;
	end
	if self.item ~= nil then
		self.item:dispose();
		self.item = nil;
	end
	if self.highlightEff ~= nil then
		self.highlightEff:dispose();
		self.highlightEff = nil;
	end
	if self.scrollText ~= nil then
		self.scrollText:dispose();
		self.scrollText = nil;
	end
	self:superCall("dispose");
end