Lua_SpiritShopItem = class("Lua_SpiritShopItem", Lua_DisplayObject);
function Lua_SpiritShopItem:ctor(p)
	self:superCall("ctor", p, "SpiritShopItem_skin");
end

function Lua_SpiritShopItem:buildShowItem()
	self:superCall("buildShowItem");

	self.item = Lua_ItemIcon.new(self.content);
	self.item:setCanClick(false);
	self.item:setSiblingIndex(2);
	self.item:setLocation(0, 25, 0);
	self.item:setScale(0.9, 0.9);
end

function Lua_SpiritShopItem.Get:showData()
	return self._data;
end

function Lua_SpiritShopItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	self.item:setData(data.itemVo);
	if data.discount > 0 then
		self.discountIcon:setEnable(true);
		self.discountIcon:setAltas("shop_atlas_1", "xui_sd_label_"..data.discount);
	-- elseif data.recommend > 0 then
	-- 	self.discountIcon:setEnable(true);
	-- 	self.discountIcon:setAltas("shop_atlas_1", "推荐图片");
	else
		self.discountIcon:setEnable(false);
	end

	if data.moneyCount ~= 0 then
		local toolVo = Lua_ToolVo.createToolVo(data.moneyType);
		if toolVo ~= nil then
			self.costIcon:setAltas(toolVo.iconAtlas, toolVo.iconSprite);
		end

		if DataCenter.packData:getItemCountById(data.moneyType) < data.moneyCount then
			self.costCount.text = LanUtil.formateStr(125045, numberTrans(data.moneyCount));
		else
			self.costCount.text = numberTrans(data.moneyCount);
		end
	else
		self.costCount:setLangValue(125011);
	end
	self.costCount:resetSize();
	local maxY = self.costCount.posX + self.costCount.width;
	local minY = self.costIcon.posX - self.costIcon.width;
	local changePosY = (maxY - minY) / 2;
	self.costIcon:setLocation(-changePosY + self.costIcon.width, self.costIcon.posY, 0);
	self.costCount:setLocation(changePosY - self.costCount.width, self.costCount.posY, 0);

	self.sellOutObj:SetActive(data.isSoldOut);
end

function Lua_SpiritShopItem:showHighlightEff(bShow)
	local effectName = self._data.highlightEff;
	if bShow and effectName ~= nil then
		if self.highlightEff == nil then
			self.highlightEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/"..effectName, effectName, 0, 25);
		end
		self.highlightEff:setEnable(false);
		self.highlightEff:setEnable(true);
	else
		if self.highlightEff ~= nil then
			self.highlightEff:setEnable(false);
		end
	end
end

function Lua_SpiritShopItem:checkOutBound(showRect)
	local rect = Lua_Rectangle.new(self.itemX - 50, self.itemY - 50, 100, 100);
	if showRect:containeRect(rect) == true then
		self.item:showEffect(true);
		if self._data.highlightEff ~= nil and self.highlightEff ~= nil then
			self.highlightEff:setEnable(true);
		end
	else
		self.item:showEffect(false);
		if self.highlightEff ~= nil then
			self.highlightEff:setEnable(false);
		end
	end
end

function Lua_SpiritShopItem:onPressClick()
	if self._data ~= nil then
		-- 是否点击商品道具
		local winPos = LuaUtil.getTouchPosInverseObj(self.mainContent);
		if self.item:checkInBound(winPos.x, winPos.y) then
			local tvo = Lua_ToolVo.createToolVo(self._data.itemId);
			DataCenter.packUtil:showItemInfo(tvo);
			return;
		end

		if self._data.isSoldOut then
			OperateAlert.showLangValue(125014);
		elseif self._data.vip_level > DataCenter.roleData.vip then
			OperateAlert.showLangValue(125021);
		else
			if DataCenter.moneyData:isMoneyEnough(self._data.moneyType, self._data.moneyCount, true, true) then
				local param = {
					id = self._data.itemId, -- 购买道具id
					itemCount = self._data.itemAmount, -- 购买一份商品所携带的数量

					limitCount = self._data.leftTimes, -- 限购数量，小于0不显示， = 0显示不限购， 默认为1,
					costId = self._data.moneyType, -- 消耗道具id
					costCount = self._data.moneyCount, -- 消耗道具数量
					tipStr = "",
					isShowTipWindow = false, -- 点击购买按钮时，是否显示提示窗口
					isLimitBtn = true, -- 最小、最大、-、+按钮是否可点击
					isShowBackBtn = false, -- 是否显示返回按钮
					cancelBtnStr = LanUtil.getValue(125051), -- 默认取消
					sureBtnStr = LanUtil.getValue(125052), -- 默认确定
					owner = self, 
					callFunc = self.onSureBuy, -- 回调事件
					priceStyle = 1 -- 价格显示类型
				};
				Lua_WindowUtil.openWin("Lua_ShoppingGoodsWindow", Lua_WinParam.ACTION_OPEN, param);
			end
		end
	end
end

-- 判断是否范围内
function Lua_SpiritShopItem:checkInBound(posX, posY)
	local half_w = self.bg.width * self.bg.scaleX / 2;
	local half_h = self.bg.height * self.bg.scaleY  / 2;
	self.minX = self.posX - half_w;
	self.maxX = self.posX + half_w;
	self.minY = self.posY - half_h;
	self.maxY = self.posY + half_h;
	return posX >= self.minX and posX <= self.maxX and posY >= self.minY and posY <= self.maxY;
end

function Lua_SpiritShopItem:onSureBuy(itemId, selectNum)
	Lua_MsgUtil.callFunc("SPIRIT_SHOP_EFFECT_CALLFUN_CLICK", false);
	Lua_ProxyManager.getProxy("Lua_ShopProxy"):sBuyShopItem(self._data.id, self._data.shopType, selectNum, self._data.index);
end

function Lua_SpiritShopItem:dispose()
	TweenUtil.getInstance():stop(self.content);
	if self.item ~= nil then
		self.item:dispose();
		self.item = nil;
	end
	if self.highlightEff ~= nil then
		self.highlightEff:dispose();
		self.highlightEff = nil;
	end
	self._data = nil;
	
	self:superCall("dispose");
end